@@ -8,7 +8,7 @@ use Statistics::Lite qw(max mean median stddev);
 use String::Util qw(hascontent nocontent);
 use Config;
 
-$Lingua::Norms::SUBTLEX::VERSION = '0.01';
+$Lingua::Norms::SUBTLEX::VERSION = '0.02';
 
 =head1 NAME
 
@@ -16,11 +16,11 @@ Lingua::Norms::SUBTLEX - Retrieve frequency values and frequency-based lists fro
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
- # the basics:
+ use feature qw(say);
  use Lingua::Norms::SUBTLEX;
  my $subtlex = Lingua::Norms::SUBTLEX->new();
  my $bool = $subtlex->is_normed(string => 'fuip'); # isa_word ? 
@@ -40,7 +40,9 @@ Version 0.01
 
 =head1 DESCRIPTION
 
-The SUBTLEX-US word-frequency list comprises 74,286 letter-strings, with their frequencies of occurrence and parts-of-speech, based on a corpus of some 30 million words from film and television subtitles. For details, see L<http://expsy.ugent.be/subtlexus/|http://expsy.ugent.be/subtlexus/> to download the file and install it, and L<REFERENCES|Lingua::Norms::SUBTLEX/REFERENCES>. Only a small sample from the SUBTLEX-US list is included in the installation distribtuion used for testing purposes (or the archive would be about 2 MB, and testing would take about 35 secs). The complete file should be downloaded, named "US_2007.csv", and placed in an appropriate directory, with its location specified in object construction, as described below. Other language files from this project might be supported by this module but have not been tested to date.
+The module facilitates access to raw data and descriptive statistics on word-frequency and parts-of-speech, as provided in the SUBTLEX-US study of Brysbaert and New (2009). This comprised a study of 74,286 letter-strings, with frequencies of occurrence within a corpus of some 30 million words from the subtitles of 8,388 film and television episodes. The frequency data obtained in this way have been shown to offer more psychologically predictive measures than those derived from books, newsgroup posts, and similar. See L<http://expsy.ugent.be/subtlexus/|http://expsy.ugent.be/subtlexus/> for details, and to download the datafile and install it. See also the papers listed in L<REFERENCES|Lingua::Norms::SUBTLEX/REFERENCES>. 
+
+Only a small sample from the SUBTLEX-US datafile is included for testing purposes in the installation distribution. The complete file should be downloaded, named "US_2007.csv", and placed in an appropriate directory, with its location specified in object construction, as described below. Other language files from this project might be supported by this module but have not been tested to date.
 
 =head1 SUBROUTINES/METHODS
 
@@ -52,7 +54,7 @@ All methods are called via the class object, and with named (hash of) arguments,
  $subtlex = Lingua::Norms::SUBTLEX->new(dir => 'file_location'); # where US_2007.csv is located
  $subtlex = Lingua::Norms::SUBTLEX->new(dir => 'file_location', filename => 'foo'); # where datafile is located
 
-Returns a class object for accessing the other methods. An optional argument B<dir> can be given to specify the directory in which the SUBTLEX table is stored. If this is not specified, then the "Lingua/Norms/SUBTLEX" directory within the 'sitelib' configured for the local Perl installation is assumed to be the location (i.e., using Config.pm, and where the sample file should have been stored upon installation of the module). The method will C<croak> if the given B<filename> or the default, "US_2007.csv" in this directory cannot be C<open>ed (or C<close>d). 
+Returns a class object for accessing other methods. An optional argument B<dir> can be given to specify the directory in which the SUBTLEX table is stored. If this is not specified, then the "Lingua/Norms/SUBTLEX" directory within the 'sitelib' configured for the local Perl installation is assumed to be the location (i.e., using Config.pm, and where the sample file should have been stored upon installation of the module). The method will C<croak> if the given B<filename> or the default, "US_2007.csv" in this directory cannot be C<open>ed (or C<close>d). 
 
 =cut
 
@@ -74,7 +76,7 @@ sub new {
           File::Spec->catdir( $Config{'sitelib'}, qw/Lingua Norms SUBTLEX/ );
     }
 
-    # Now try opening and reading the file US_2007.csv from within this directory:
+  # Now try opening and reading the file US_2007.csv from within this directory:
     my $filename = $args{'filename'} ? delete $args{'filename'} : 'US_2007.csv';
     my $path = File::Spec->catfile( $self->{'dir'}, $filename );
     croak
@@ -122,7 +124,7 @@ sub is_normed {
     while (<$fh>) {
         next if $. == 1;         # skip headings
         /^([^,]+)/sxm
-        or next  ;    # isolate first token ahead of a comma as $1 in this csv file
+          or next; # isolate first token ahead of a comma as $1 in this csv file
         if ( $str eq $1 ) {    # first token equals given string?
             $res = 1;          # set result to return as true
             last;              # got it, so abort the look-up
@@ -146,7 +148,7 @@ sub freq {
     croak
       'No word to test; pass a letter-string named \'string\' to the function'
       if !$args{'string'};
-    return _get_field( $self, $args{'string'}, 5 );
+    return _get_fieldvalue( $self, $args{'string'}, 5 );
 }
 
 =head3 lfreq
@@ -162,14 +164,14 @@ sub lfreq {
     croak
       'No word to test; pass a letter-string named \'string\' to the function'
       if !$args{'string'};
-    return _get_field( $self, $args{'string'}, 6 );
+    return _get_fieldvalue( $self, $args{'string'}, 6 );
 }
 
 =head3 zipf
 
  $zipf = $subtlex->zipf(string => 'aword');
 
-Returns zipf frequency for the word passed as B<string>, or the empty-string if the string is not represented in the norms. See Van Heuven et al. (in press) and L<http://crr.ugent.be/archives/1352|http://crr.ugent.be/archives/1352>.
+Returns zipf frequency for the word passed as B<string>, or the empty-string if the string is not represented in the norms. The Zipf scale ranges from 1 to 7, with values of 1-3 representing low frequency words, and values of 4-7 representing high frequency words. See Van Heuven et al. (2014) and L<http://crr.ugent.be/archives/1352|http://crr.ugent.be/archives/1352>.
 
 =cut
 
@@ -178,7 +180,37 @@ sub zipf {
     croak
       'No word to test; pass a letter-string named \'string\' to the function'
       if !$args{'string'};
-    return _get_field( $self, $args{'string'}, 14 );
+    return _get_fieldvalue( $self, $args{'string'}, 14 );
+}
+
+=head3 cd_pct
+
+ $cd = $subtlex->cd_pct(string => 'aword');
+
+Returns a percentage measure to two decimal places of the number of films/TV episodes in which the given string was included in its subtitles. This corresponds to the measure "SUBTLCD" described in Brysbaert and New (2009). Note: where "cd" stands for "contextual diversity."
+
+=cut
+
+sub cd_pct {
+    my ( $self, %args ) = @_;
+    croak
+      'No word to test; pass a letter-string named \'string\' to the function'
+      if !$args{'string'};
+    return _get_fieldvalue( $self, $args{'string'}, 7 );
+}
+
+=head3 cd_log
+
+Returns log10(L<cd_pct|cd_pct> + 1) for the given string, with 4-digit precision. This corresponds to the measure "Lg10CD" described in Brysbaert and New (2009), where it is stated that "this is the best value to use if one wants to match words on word frequency" (p. 988). Note: "cd" stands for "contextual diversity," which is based on the number of films and TV episodes in which the string was represented.
+
+=cut
+
+sub cd_log {
+    my ( $self, %args ) = @_;
+    croak
+      'No word to test; pass a letter-string named \'string\' to the function'
+      if !$args{'string'};
+    return _get_fieldvalue( $self, $args{'string'}, 8 );
 }
 
 =head3 freqhash
@@ -333,7 +365,7 @@ sub on_count {
     open my $fh, q{<}, $self->{'path'} or die "$!\n";
     while (<$fh>) {
         next if $. == 1;    # skip column heading line
-        /^([^,]+)/sxm or next; 
+        /^([^,]+)/sxm or next;
         my $test = lc($1);
         if ( $ortho->are_orthons( $word, $test ) ) {
             push @orthons, $test;
@@ -410,7 +442,7 @@ sub on_zipf_mean {
 
 I<Alias>: ldist
 
-Returns the mean L<Levenshtein Distance|http://www.let.rug.nl/%7Ekleiweg/lev/levenshtein.html> from a word to its B<lim> closest orthographic neighbours. The default B<lim>it is 20, as defined in Yarkoni et al. (2008). The module uses the matrix-based calculation of Levenshtein Distance as implemented in this author's L<Lingua::Orthon|Lingua::Orthon> module. No defined value is returned if no Levenshtein Distance is found (whereas zero would connote "identical to everything").
+Returns the mean L<Levenshtein Distance|http://www.let.rug.nl/%7Ekleiweg/lev/levenshtein.html> from a letter-string to its B<lim> closest orthographic neighbours. The default B<lim>it is 20, as defined in Yarkoni et al. (2008). The module uses the matrix-based calculation of Levenshtein Distance as implemented in this author's L<Lingua::Orthon|Lingua::Orthon> module. No defined value is returned if no Levenshtein Distance is found (whereas zero would connote "identical to everything").
 
 =cut
 
@@ -418,9 +450,7 @@ sub on_ldist {
     my ( $self, %args ) = @_;
     croak 'No words to test' if !$args{'string'};
     $args{'lim'} ||= 20;
-    my $frq_aref =
-      _get_orthon_ldist( $args{'string'}, $self->{'path'}, $args{'lim'} );
-    return scalar @{$frq_aref} ? mean( @{$frq_aref} ) : undef;
+    return _get_orthon_ldist( $args{'string'}, $self->{'path'}, $args{'lim'} );
 }
 *ldist = \&on_ldist;
 
@@ -457,8 +487,8 @@ sub list_strings {
     if ( ref $args{'freq'} ) {
         ( $min, $max ) = _set_minmax( $args{'freq'} );
     }
-    elsif( ref $args{'zipf'}) {
-     ( $min, $max ) = _set_minmax( $args{'zipf'} );
+    elsif ( ref $args{'zipf'} ) {
+        ( $min, $max ) = _set_minmax( $args{'zipf'} );
     }
 
     my $regex;
@@ -483,8 +513,8 @@ sub list_strings {
         my @line = split /,/sxm, $_;
         next if defined $regex   and $line[0] !~ $regex;
         next if defined $cv_patt and $line[0] !~ $cv_patt;
-        my $i =  ref $args{'freq'} ? 5 :  ref $args{'zipf'} ? 14 : ''; 
-        if (hascontent($i)) {
+        my $i = ref $args{'freq'} ? 5 : ref $args{'zipf'} ? 14 : '';
+        if ( hascontent($i) ) {
             if ( $line[$i] >= $min ) {
                 if ( defined $max ) {
                     if ( $line[$i] <= $max ) {
@@ -499,7 +529,6 @@ sub list_strings {
     }
     close $fh or croak;
 
-    
     if ( ref $args{'length'} ) {
         my (@sub_list) = ();
         my ( $mina, $maxa ) = _set_minmax( $args{'length'} );
@@ -538,7 +567,7 @@ sub all_strings {
     open my $fh, q{<}, $self->{'path'} or croak $!;
     while (<$fh>) {
         next if $. == 1;    # skip column heading line
-        /^([^,]+)/sxm or next; 
+        /^([^,]+)/sxm or next;
         push @list, $1;
     }
     close $fh or croak;
@@ -579,7 +608,9 @@ sub random_string {
 
 =head3 nlines
 
-Returns the number of lines, less the column headings, in the installed US_2007.csv file used by other methods read.
+ $num = $subtlex->nlines();
+
+Returns the number of lines, less the column headings, in the installed US_2007.csv file used by other methods read. Expects/accepts no arguments.
 
 =cut
 
@@ -606,7 +637,7 @@ sub _get_orthon_f {
     open( my $fh, q{<}, $path ) or croak $!;
     while (<$fh>) {
         next if $. == 1;    # skip column heading line
-        /^([^,]+)/xsm or next;      # capture first token, a word
+        /^([^,]+)/xsm or next;    # capture first token, a word
         my $test = lc($1);
         if ( $ortho->are_orthons( $word, $test ) ) {    # Lingua::Orthon method
             chomp $_;    # remove linebreak from line of data from file <F>
@@ -624,30 +655,23 @@ sub _get_orthon_ldist {
     require Lingua::Orthon;
     my $ortho  = Lingua::Orthon->new();
     my @ldists = ();
-    my @freqs  = ();
-    my $idx    = 5;
     open( my $fh, q{<}, $path ) or croak $!;
-
+    my @tests = ();
     while (<$fh>) {
         next if $. == 1;    # skip column heading line
         /^([^,]+)/sxm or next;
         my $test = lc($1);
-        my $ldist = $ortho->ldist( $word, $test );
-        if ( ref $ldist and @{$ldist} and $ldist < $ldists[-1] ) {
-            pop @ldists;
-            push @ldists, @$ldist;
-        }
-        if ( $ortho->are_orthons( $word, $test ) ) {
-            chomp $_;
-            my @line = split /,/xsm, $_;
-            push @freqs, $line[$idx];
-        }
+        push @tests, $test;
+        push @ldists, $ortho->ldist( $word, $test );
     }
     close $fh;
-    return \@freqs;
+    my @sorted = sort { $a <=> $b } @ldists;
+    my @lim    = @sorted[ 0 .. $lim - 1 ];
+    my $mean   = mean(@lim);
+    return $mean;
 }
 
-sub _get_field {
+sub _get_fieldvalue {
     my ( $self, $str, $field_i ) = @_;
     $str = lc($str);
     my $val = '';    # default value returned is empty string
@@ -714,25 +738,25 @@ Croaked upon a number of methods that expect a value for the named argument B<st
 
 =head1 DEPENDENCIES
 
-Statistics::Lite
+L<Statistics::Lite|Statistics::Lite>
 
-Lingua::Orthon
+L<Lingua::Orthon|Lingua::Orthon>
 
-String::Util
+L<String::Util|String::Util>
 
-File::RandomLine
+L<File::RandomLine|File::RandomLine>
 
 =head1 REFERENCES
 
-B<Brysbaert, M., & New, B.> (2009). Moving beyond Kucera and Francis: A critical evaluation of current word frequency norms and the introduction of a new and improved word frequency measure for American English. I<Behavior Research Methods>, I<41>, 977-990. doi: 10.3758/BRM.41.4.977.
+B<Brysbaert, M., & New, B.> (2009). Moving beyond Kucera and Francis: A critical evaluation of current word frequency norms and the introduction of a new and improved word frequency measure for American English. I<Behavior Research Methods>, I<41>, 977-990. doi: L<10.3758/BRM.41.4.977|http://dx.doi.org/10.3758/BRM.41.4.977>
 
-B<Brysbaert, M., New, B., & Keuleers,E.> (2012). Adding part-of-speech information to the SUBTLEX-US word frequencies. I<Behavior Research Methods>, I<44>, 991-997.
+B<Brysbaert, M., New, B., & Keuleers,E.> (2012). Adding part-of-speech information to the SUBTLEX-US word frequencies. I<Behavior Research Methods>, I<44>, 991-997. doi: L<10.3758/s13428-012-0190-4|http://dx.doi.org/10.3758/s13428-012-0190-4>
 
 B<Coltheart, M., Davelaar, E., Jonasson, J. T., & Besner, D.> (1977). Access to the internal lexicon. In S. Dornic (Ed.), I<Attention and performance> (Vol. 6, pp. 535-555). London, UK: Academic.
 
-B<Van Heuven, W. J. B., Mandera, P., Keuleers, E., & Brysbaert, M.> (in press). SUBTLEX-UK: A new and improved word frequency database for British English. I<Quarterly Journal of Experimental Psychology>.
+B<Van Heuven, W. J. B., Mandera, P., Keuleers, E., & Brysbaert, M.> (2014). SUBTLEX-UK: A new and improved word frequency database for British English. I<Quarterly Journal of Experimental Psychology>, I<67>, 1176-1190. doi: L<10.1080/17470218.2013.850521|http://dx.doi.org/10.1080/17470218.2013.850521>
 
-B<Yarkoni, T., Balota, D. A., & Yap, M.> (2008). Moving beyond Coltheart's I<N>: A new measure of orthographic similarity. I<Psychonomic Bulletin and Review>, I<15>, 971-979. doi: 10.3758/PBR.15.5.971.
+B<Yarkoni, T., Balota, D. A., & Yap, M.> (2008). Moving beyond Coltheart's I<N>: A new measure of orthographic similarity. I<Psychonomic Bulletin and Review>, I<15>, 971-979. doi: L<10.3758/PBR.15.5.971|http://dx.doi.org/10.3758/PBR.15.5.971>
 
 =head1 AUTHOR
 
@@ -740,8 +764,8 @@ Roderick Garton, C<< <rgarton at cpan.org> >>
 
 =head1 BUGS AND LIMITATIONS
 
-Please report any bugs or feature requests to C<bug-lingua-norms-subtlfreq-0.01 at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Lingua-Norms-SUBTLEX-0.01>.  I will be notified, and then you'll
+Please report any bugs or feature requests to C<bug-lingua-norms-subtlfreq-0.02 at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Lingua-Norms-SUBTLEX-0.02>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
 =head1 TO DO
@@ -771,25 +795,25 @@ You can also look for information at:
 
 =item * RT: CPAN's request tracker (report bugs here)
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Lingua-Norms-SUBTLEX-0.01>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Lingua-Norms-SUBTLEX-0.02>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/Lingua-Norms-SUBTLEX-0.01>
+L<http://annocpan.org/dist/Lingua-Norms-SUBTLEX-0.02>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/Lingua-Norms-SUBTLEX-0.01>
+L<http://cpanratings.perl.org/d/Lingua-Norms-SUBTLEX-0.02>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/Lingua-Norms-SUBTLEX-0.01/>
+L<http://search.cpan.org/dist/Lingua-Norms-SUBTLEX-0.02/>
 
 =back
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014 Roderick Garton.
+Copyright 2014-2015 Roderick Garton.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
